@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011-2012 Philipp Spitzer, gregor herrmann, Stefan Stahl
+ * Copyright (C) 2011-2013 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -20,7 +20,7 @@
 #include "application.h"
 #include "errormessage.h"
 
-#include <ormrecord.h>
+#include "ormrecord.h"
 
 // if the application uses exceptions,
 // there is always a possibility that some will leak uncached from event handler
