@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011-2012 Philipp Spitzer, gregor herrmann, Stefan Stahl
+ * Copyright (C) 2011-2013 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -103,8 +103,8 @@ void ConferenceEditor::addClicked()
 {
     UrlInputDialog url_input(this);
     switch (url_input.exec()) {
-    case UrlInputDialog::HaveUrl: emit haveConferenceUrl(url_input.url()); break;
-    case UrlInputDialog::HaveFile: emit haveConferenceFile(url_input.url()); break;
+    case UrlInputDialog::HaveUrl: emit haveConferenceUrl(url_input.url(), 0); break;
+    case UrlInputDialog::HaveFile: emit haveConferenceFile(url_input.url(), 0); break;
     case UrlInputDialog::Cancel: return;
     }
 }
@@ -143,21 +143,21 @@ void ConferenceEditor::changeUrlClicked()
 
 void ConferenceEditor::refreshClicked()
 {
-    if (selected_id < 0) return;
+    if (selected_id <= 0) return;
     const Conference& selectedConf = Conference::getById(selected_id);
     QString url = selectedConf.url();
 
     if (url.isEmpty()) {
         static const QString format("Schedule URL for %1 is not set. Enter the schedule URL:");
         bool ok;
-        QString url = QInputDialog::getText(this, "URL Input", format.arg(selectedConf.title()), QLineEdit::Normal, QString(), &ok);
+        url = QInputDialog::getText(this, "URL Input", format.arg(selectedConf.title()), QLineEdit::Normal, QString(), &ok);
         if (!ok) return;
         // first save it, to remain if fetch fails
         emit changeUrlRequested(selected_id, url);
     }
     // fetch
     importStarted(); // just to show the progress bar
-    emit haveConferenceUrl(url);
+    emit haveConferenceUrl(url, selected_id);
 }
 
 void ConferenceEditor::importStarted()
@@ -178,8 +178,7 @@ void ConferenceEditor::showParsingProgress(int progress)
     QApplication::processEvents();
 }
 
-void ConferenceEditor::importFinished(const QString& title)
-{
+void ConferenceEditor::importFinished(int conferenceId) {
     addBtn->show();
     // removeItem should be shown later, but it takes some time,
     // and not looks good
@@ -190,14 +189,10 @@ void ConferenceEditor::importFinished(const QString& title)
 
     QApplication::processEvents();
 
-    int num = model->rowCount();
-    for (int i = 0; i < num; i++) {
-        QModelIndex item = model->index(i, 0);
-        if (model->data(item) == title) {
-            emit wantCurrent(item, QItemSelectionModel::SelectCurrent);
-            return;
-        }
-    }
-    itemSelected(QModelIndex(), QModelIndex());
+    QModelIndex item = model->indexFromId(conferenceId);
+    if (item.isValid())
+        emit wantCurrent(item, QItemSelectionModel::SelectCurrent);
+    else
+        itemSelected(QModelIndex(), QModelIndex());
 }
 
