@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011-2012 Philipp Spitzer, gregor herrmann, Stefan Stahl
+ * Copyright (C) 2011-2013 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -22,13 +22,13 @@
 
 #include <QDialog>
 #include "ui_eventdialog.h"
-#include <event.h>
+#include "event.h"
 
 class EventDialog : public QDialog, Ui::EventDialog
 { 
     Q_OBJECT
 public:
-    EventDialog(const int &aEventId, QWidget *aParent = NULL);
+    EventDialog(int conferencdId, int eventId, QWidget *parent = 0);
     ~EventDialog() {}
 private slots:
     void favouriteClicked();
@@ -36,6 +36,7 @@ private slots:
 signals:
     void eventChanged(int aEventId, bool favouriteChanged); // emited when user changes some event details, eg. sets it Favourite
 private:
+    int mConferenceId;
     int mEventId;
 };
 
