@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011-2012 Philipp Spitzer, gregor herrmann, Stefan Stahl
+ * Copyright (C) 2011-2013 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -25,39 +25,50 @@
 #include <QNetworkAccessManager>
 #include <QNetworkReply>
 
-#include <sqlengine.h>
+#include "sqlengine.h"
 
-#include <track.h>
-#include <eventmodel.h>
-#include <delegate.h>
+#include "track.h"
+#include "eventmodel.h"
+#include "delegate.h"
+#include "room.h"
 
-#include <conference.h>
+#include "conference.h"
 
 #include <QDialog>
 #include <QMessageBox>
 
 #include "ui_about.h"
-#include <eventdialog.h>
+#include "eventdialog.h"
 #include "daynavigatorwidget.h"
 #include "settingsdialog.h"
 #include "conferenceeditor.h"
 #include "schedulexmlparser.h"
 #include "errormessage.h"
 
-#include <tabcontainer.h>
-#include <appsettings.h>
+#include "tabcontainer.h"
+#include "appsettings.h"
 
 const QString PROXY_USERNAME;
 const QString PROXY_PASSWD;
 
-MainWindow::MainWindow(int aEventId, QWidget *aParent)
-    : QMainWindow(aParent)
-    , conferenceModel(new ConferenceModel(this))
-    , mXmlParser(new ScheduleXmlParser(this))
-    , mNetworkAccessManager(new QNetworkAccessManager(this))
-{
+MainWindow::MainWindow(QWidget* parent): QMainWindow(parent) {
     setupUi(this);
 
+    // Open database
+    sqlEngine = new SqlEngine(this);
+    searchTabContainer->setSqlEngine(sqlEngine);
+    connect(sqlEngine, SIGNAL(dbError(QString)), this, SLOT(showError(QString)));
+    sqlEngine->open();
+    sqlEngine->createOrUpdateDbSchema();
+
+    conferenceModel = new ConferenceModel(this);
+    mXmlParser = new ScheduleXmlParser(sqlEngine, this);
+    mNetworkAccessManager = new QNetworkAccessManager(this);
+    systemTrayIcon = new QSystemTrayIcon(qApp->windowIcon(), this);
+    alarmTimer = new QTimer(this);
+
+    alarmTimer->setInterval(60000);
+    alarmTimer->start();
     saved_title = windowTitle();
 
 #ifdef N810
@@ -69,12 +80,6 @@ MainWindow::MainWindow(int aEventId, QWidget *aParent)
     if(!AppSettings::contains("proxyIsDirectConnection"))
         AppSettings::setDirectConnection(true);
 
-    /*
-    if(AppSettings::isDirectConnection())
-    {
-        qDebug() << "Setting-up proxy: " << AppSettings::proxyAddress() << ":" << AppSettings::proxyPort();
-    }
-    */
     QNetworkProxy proxy(
             AppSettings::isDirectConnection() ? QNetworkProxy::NoProxy : QNetworkProxy::HttpProxy,
             AppSettings::proxyAddress(),
@@ -100,7 +105,19 @@ MainWindow::MainWindow(int aEventId, QWidget *aParent)
     // search result has changed
     connect(searchTabContainer, SIGNAL(searchResultChanged()), SLOT(onSearchResultChanged()));
 
+    // systm tray icon
+    connect(systemTrayIcon, SIGNAL(messageClicked()), SLOT(onSystemTrayMessageClicked()));
+    connect(systemTrayIcon, SIGNAL(activated(QSystemTrayIcon::ActivationReason)), SLOT(onSystemTrayMessageClicked()));
 
+    // timer
+    connect(alarmTimer, SIGNAL(timeout()), SLOT(onAlarmTimerTimeout()));
+
+    // add the actions from the main menu to the window, otherwise the shortcuts don't work on MAEMO
+    addAction(conferencesAction);
+    addAction(settingsAction);
+    addAction(quitAction);
+
+    // open conference
     useConference(Conference::activeConference());
     // optimization, see useConference() code
     try {
@@ -110,25 +127,17 @@ MainWindow::MainWindow(int aEventId, QWidget *aParent)
         clearTabs();
     }
 
-    // open dialog for given Event ID
-    // this is used in case Alarm Dialog request application to start
-    if(aEventId)
-    {
-        try
-        {
-            EventDialog dialog(aEventId,this);
-            dialog.exec();
-        }
-        catch(OrmNoObjectException&) {} // just start application
-        catch(...) {} // just start application
-    }
-
     connect(mNetworkAccessManager, SIGNAL(finished(QNetworkReply*)), SLOT(networkQueryFinished(QNetworkReply*)));
-
     connect(mXmlParser, SIGNAL(parsingScheduleBegin()), conferenceModel, SLOT(newConferenceBegin()));
-    connect(mXmlParser, SIGNAL(parsingScheduleEnd(const QString&)), conferenceModel, SLOT(newConferenceEnd(const QString&)));
+    connect(mXmlParser, SIGNAL(parsingScheduleEnd(int)), conferenceModel, SLOT(newConferenceEnd(int)));
 }
 
+
+MainWindow::~MainWindow() {
+    sqlEngine->close();
+}
+
+
 void MainWindow::on_aboutAction_triggered()
 {
     QDialog dialog(this);
@@ -147,7 +156,7 @@ void MainWindow::on_reloadAction_triggered() {
     if (confId== -1) return;
     Conference active = Conference::getById(confId);
     if (active.url().isEmpty()) return;
-    importFromNetwork(active.url());
+    importFromNetwork(active.url(), confId);
     setEnabled(false);
 }
 
@@ -220,20 +229,67 @@ void MainWindow::onSearchResultChanged() {
 }
 
 
-void MainWindow::useConference(int id)
+void MainWindow::onSystemTrayMessageClicked() {
+    systemTrayIcon->hide();
+}
+
+
+void MainWindow::onAlarmTimerTimeout() {
+    // determine if an alarm is set on an event that's starting soon
+    QList<Event> events = Event::getImminentAlarmEvents(AppSettings::preEventAlarmSec(), Conference::activeConference());
+    if (events.empty()) return;
+
+    // build a message string
+    Event event;
+    QString title;
+    QString message;
+    if (events.size() == 1) {
+        event = events.first();
+        title = tr("Next event at %1").arg(event.start().toString("HH:mm"));
+        message = tr("\"%1\"\n(%2)").arg(event.title()).arg(event.room()->name());
+    } else {
+        title = tr("%1 upcoming events").arg(events.size());
+        QStringList messages;
+        foreach (event, events) {
+            messages += tr("%1: \"%2\" (%3)").arg(event.start().toString("HH:mm")).arg(event.title()).arg(event.room()->name());
+        }
+        message = messages.join("\n");
+    }
+
+    // and delete the corresponding alarm
+    foreach (event, events) {
+        event.setHasAlarm(false);
+        event.update("alarm");
+        onEventChanged(event.id(), false);
+    }
+
+    // show message
+    systemTrayIcon->show();
+    // The next two lines are to prevent a very strange position of the message box the first time at X11/aweseome (not Win32/XP)
+    systemTrayIcon->showMessage("ConfClerk", "Your upcoming events", QSystemTrayIcon::Information);
+    qApp->processEvents();
+    systemTrayIcon->showMessage(title, message, QSystemTrayIcon::Information, 60*60*24*1000);
+    QApplication::alert(this);
+    QApplication::beep();
+}
+
+
+void MainWindow::useConference(int conferenceId)
 {
-    if (id == -1)  // in case no conference is active
+    if (conferenceId == -1)  // in case no conference is active
     {
         unsetConference();
         return;
     }
     try {
-        Conference::getById(Conference::activeConference()).update("active",0);
-        Conference new_active = Conference::getById(id);
-        new_active.update("active",1);
+        int oldActiveConferenceId = Conference::activeConference();
+        bool switchActiveConference = conferenceId != oldActiveConferenceId;
+        if (switchActiveConference) Conference::getById(oldActiveConferenceId).update("active", 0);
+        Conference activeConference = Conference::getById(conferenceId);
+        if (switchActiveConference) activeConference.update("active",1);
 
         // looks like it does not work at n900
-        setWindowTitle(new_active.title());
+        setWindowTitle(activeConference.title());
 
         // optimization.
         // dont run initTabs() here
@@ -268,6 +324,7 @@ void MainWindow::initTabs()
 
         // 'dayNavigator' emits signal 'dateChanged' after setting valid START:END dates
         dayNavigator->setDates(startDate, endDate);
+        nowAction->trigger();
     }
 }
 
@@ -287,6 +344,12 @@ void MainWindow::unsetConference()
     setWindowTitle(saved_title);
 }
 
+
+void MainWindow::showError(const QString& message) {
+    error_message(message);
+}
+
+
 void MainWindow::on_settingsAction_triggered()
 {
     SettingsDialog dialog;
@@ -317,8 +380,8 @@ void MainWindow::on_conferencesAction_triggered()
 {
     ConferenceEditor dialog(conferenceModel, this);
 
-    connect(&dialog, SIGNAL(haveConferenceUrl(const QString&)), SLOT(importFromNetwork(const QString&)));
-    connect(&dialog, SIGNAL(haveConferenceFile(const QString&)), SLOT(importFromFile(const QString&)));
+    connect(&dialog, SIGNAL(haveConferenceUrl(const QString&, int)), SLOT(importFromNetwork(const QString&, int)));
+    connect(&dialog, SIGNAL(haveConferenceFile(const QString&, int)), SLOT(importFromFile(const QString&, int)));
     connect(&dialog, SIGNAL(removeConferenceRequested(int)), SLOT(removeConference(int)));
     connect(&dialog, SIGNAL(changeUrlRequested(int, const QString&)),
                     SLOT(changeConferenceUrl(int, const QString&)));
@@ -328,7 +391,7 @@ void MainWindow::on_conferencesAction_triggered()
 
     connect(mXmlParser, SIGNAL(parsingScheduleBegin()), &dialog, SLOT(importStarted()));
     connect(mXmlParser, SIGNAL(progressStatus(int)), &dialog, SLOT(showParsingProgress(int)));
-    connect(mXmlParser, SIGNAL(parsingScheduleEnd(const QString&)), &dialog, SLOT(importFinished(const QString&)));
+    connect(mXmlParser, SIGNAL(parsingScheduleEnd(int)), &dialog, SLOT(importFinished(int)));
 
     connect(this, SIGNAL(conferenceRemoved()), &dialog, SLOT(conferenceRemoved()));
 
@@ -349,33 +412,34 @@ void MainWindow::networkQueryFinished(QNetworkReply *aReply) {
         QUrl redirectUrl = aReply->attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl();
         if (!redirectUrl.isEmpty()) {
             if (redirectUrl != aReply->request().url()) {
-                importFromNetwork(redirectUrl.toString());
+                importFromNetwork(redirectUrl.toString(), aReply->request().attribute(QNetworkRequest::User).toInt());
                 return; // don't enable controls
             } else {
                 error_message(QString("Error: Cyclic redirection from %1 to itself.").arg(redirectUrl.toString()));
             }
         } else {
-            importData(aReply->readAll(), aReply->url().toEncoded());
+            importData(aReply->readAll(), aReply->url().toEncoded(), aReply->request().attribute(QNetworkRequest::User).toInt());
         }
     }
     setEnabled(true);
 }
 
-void MainWindow::importData(const QByteArray &aData, const QString& url)
+void MainWindow::importData(const QByteArray &aData, const QString& url, int conferenceId)
 {
-    mXmlParser->parseData(aData, url);
+    mXmlParser->parseData(aData, url, conferenceId);
 }
 
-void MainWindow::importFromNetwork(const QString& url)
+void MainWindow::importFromNetwork(const QString& url, int conferenceId)
 {
     QNetworkRequest request;
     request.setUrl(QUrl(url));
+    request.setAttribute(QNetworkRequest::User, conferenceId);
 
     mNetworkAccessManager->setProxy(QNetworkProxy::applicationProxy());
     mNetworkAccessManager->get(request);
 }
 
-void MainWindow::importFromFile(const QString& filename)
+void MainWindow::importFromFile(const QString& filename, int conferenceId)
 {
     QFile file(filename);
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {    
@@ -383,19 +447,18 @@ void MainWindow::importFromFile(const QString& filename)
         error_message(format.arg(filename, QString::number(file.error())));
     }
 
-    importData(file.readAll(), "");
+    importData(file.readAll(), "", conferenceId);
 }
 
-void MainWindow::removeConference(int id)
-{
-    Conference::deleteConference(id);
-    conferenceModel->conferenceRemoved();
 
+void MainWindow::removeConference(int id) {
+    sqlEngine->deleteConference(id);
+    conferenceModel->conferenceRemoved();
     emit conferenceRemoved();
 }
 
-void MainWindow::changeConferenceUrl(int id, const QString& url)
-{
+
+void MainWindow::changeConferenceUrl(int id, const QString& url) {
     Conference::getById(id).setUrl(url);
 }
 
