@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011-2012 Philipp Spitzer, gregor herrmann, Stefan Stahl
+ * Copyright (C) 2011-2013 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -23,8 +23,8 @@
 #include <QMessageBox>
 #include <QTimer>
 
-#include <treeview.h>
-#include <delegate.h>
+#include "treeview.h"
+#include "delegate.h"
 
 #include "eventdialog.h"
 #include "room.h"
@@ -65,7 +65,7 @@ void TabContainer::itemClicked(const QModelIndex &aIndex)
     if(!aIndex.parent().isValid()) // time-group
         return;
 
-    EventDialog dialog(static_cast<Event*>(aIndex.internalPointer())->id(),this);
+    EventDialog dialog(Conference::activeConference(), static_cast<Event*>(aIndex.internalPointer())->id(),this);
 #ifdef N810
     dialog.setFixedWidth(static_cast<QWidget*>(parent())->width());
 #endif
