@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011-2012 Philipp Spitzer, gregor herrmann, Stefan Stahl
+ * Copyright (C) 2011-2013 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -23,10 +23,10 @@
 #include <QWidget>
 #include "ui_tabcontainer.h"
 
-#include <conference.h>
-#include <sqlengine.h>
-#include <conference.h>
-#include <eventmodel.h>
+#include "conference.h"
+#include "sqlengine.h"
+#include "conference.h"
+#include "eventmodel.h"
 
 class TabContainer : public QWidget, public Ui::TabContainer
 {
