@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011-2012 Philipp Spitzer, gregor herrmann, Stefan Stahl
+ * Copyright (C) 2011-2013 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -46,7 +46,7 @@ public:
     QModelIndex indexFromId(int id) const;
 public slots:
     void newConferenceBegin();
-    void newConferenceEnd(const QString& title);
+    void newConferenceEnd(int conferenceId);
     void conferenceRemoved();
 private:
     // reinitialize list from database
