@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011-2012 Philipp Spitzer, gregor herrmann, Stefan Stahl
+ * Copyright (C) 2011-2013 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -17,6 +17,7 @@
  * You should have received a copy of the GNU General Public License along with
  * ConfClerk.  If not, see <http://www.gnu.org/licenses/>.
  */
+#include "conference.h"
 #include "event.h"
 #include "room.h"
 
@@ -53,24 +54,30 @@ Event Event::getById(int id, int conferenceId) {
 
 
 QList<Event> Event::getByDate(const QDate& date, int conferenceId, QString orderBy) {
+    Q_ASSERT(conferenceId > 0);
+    Conference conference = Conference::getById(conferenceId);
+    QDateTime dayStart(date, conference.dayChangeTime(), Qt::UTC);
     QSqlQuery query;
     query.prepare(selectQuery() + QString("WHERE xid_conference = :conf AND start >= :start AND start < :end ORDER BY %1").arg(orderBy));
     query.bindValue(":conf", conferenceId);
-    query.bindValue(":start", convertToDb(date, QVariant::DateTime));
-    query.bindValue(":end", convertToDb(date.addDays(1), QVariant::DateTime));
+    query.bindValue(":start", dayStart.toTime_t());
+    query.bindValue(":end", dayStart.addDays(1).toTime_t());
     return load(query);
 }
 
-QList<Event> Event::getByDateAndRoom(const QDate& date, int conferenceId)
-{
+
+QList<Event> Event::getByDateAndRoom(const QDate& date, int conferenceId) {
+    Q_ASSERT(conferenceId > 0);
+    Conference conference = Conference::getById(conferenceId);
+    QDateTime dayStart(date, conference.dayChangeTime(), Qt::UTC);
     QSqlQuery query;
     QString aliasEvent("E");
     QString aliasEventRoom("R");
     query.prepare(QString("SELECT %1 FROM %2 %3, %4 %5 WHERE %3.xid_conference = :conf AND %3.start >= :start AND %3.start < :end AND %3.id = R.xid_event ORDER BY %5.xid_room, %3.start, %3.duration").arg(
                     columnsForSelect(aliasEvent), Event::sTableName, aliasEvent, "EVENT_ROOM", aliasEventRoom));
     query.bindValue(":conf", conferenceId);
-    query.bindValue(":start", convertToDb(date, QVariant::DateTime));
-    query.bindValue(":end", convertToDb(date.addDays(1), QVariant::DateTime));
+    query.bindValue(":start", dayStart.toTime_t());
+    query.bindValue(":end", dayStart.addDays(1).toTime_t());
 
     return load(query);
 }
@@ -94,13 +101,24 @@ QList<Event> Event::conflictEvents(int aEventId, int conferenceId) {
 }
 
 
-QList<Event> Event::getFavByDate(const QDate& date, int conferenceId)
-{
+QList<Event> Event::getImminentAlarmEvents(int maxSecToAlarm, int conferenceId) {
+    QSqlQuery query;
+    query.prepare(selectQuery() + "WHERE xid_conference = :conf AND (start < :start AND alarm = 1) ORDER BY start, duration");
+    query.bindValue(":conf", conferenceId);
+    query.bindValue(":start", convertToDb(QDateTime::currentDateTime().addSecs(maxSecToAlarm), QVariant::DateTime));
+    return load(query);
+}
+
+
+QList<Event> Event::getFavByDate(const QDate& date, int conferenceId) {
+    Q_ASSERT(conferenceId > 0);
+    Conference conference = Conference::getById(conferenceId);
+    QDateTime dayStart(date, conference.dayChangeTime(), Qt::UTC);
     QSqlQuery query;
     query.prepare(selectQuery() + QString("WHERE xid_conference = :conf AND start >= :start AND start < :end AND favourite = 1 ORDER BY start, duration"));
     query.bindValue(":conf", conferenceId);
-    query.bindValue(":start", convertToDb(date, QVariant::DateTime));
-    query.bindValue(":end", convertToDb(date.addDays(1), QVariant::DateTime));
+    query.bindValue(":start", dayStart.toTime_t());
+    query.bindValue(":end", dayStart.addDays(1).toTime_t());
 
     return load(query);
 }
@@ -164,7 +182,7 @@ QMap<QString,QString> Event::links()
         query.bindValue(":id", id());
         query.bindValue(":conf", conferenceId());
         query.exec();
-        // TODO: handle qeury error
+        // TODO: handle query error
         //qDebug() << query.lastError();
 
         while(query.next())
@@ -227,9 +245,13 @@ QList<Event> Event::getSearchResultByDate(const QDate& date, int conferenceId, Q
             throw OrmSqlException( query.lastError().text() );
         }
 
+        Q_ASSERT(conferenceId > 0);
+        Conference conference = Conference::getById(conferenceId);
+        QDateTime dayStart(date, conference.dayChangeTime(), Qt::UTC);
+
         query.bindValue(":conf", conferenceId);
-        query.bindValue(":start", convertToDb(date, QVariant::DateTime));
-        query.bindValue(":end", convertToDb(date.addDays(1), QVariant::DateTime));
+        query.bindValue(":start", dayStart.toTime_t());
+        query.bindValue(":end", dayStart.addDays(1).toTime_t());
 
         list = load(query);
     }
