@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011-2012 Philipp Spitzer, gregor herrmann, Stefan Stahl
+ * Copyright (C) 2011-2013 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -18,9 +18,9 @@
  * ConfClerk.  If not, see <http://www.gnu.org/licenses/>.
  */
 #include "eventmodel.h"
-#include <conference.h>
-#include <track.h>
-#include <room.h>
+#include "conference.h"
+#include "track.h"
+#include "room.h"
 
 const QString EventModel::COMMA_SEPARATOR = ", ";
 
@@ -29,10 +29,10 @@ EventModel::EventModel()
 
 
 void EventModel::Group::setTitle(const QList<Event>& mEvents) {
-    QTime startTime = mEvents.at(mFirstEventIndex).start().time();
-    QTime endTime(0, 0);
+    QDateTime startTime = mEvents.at(mFirstEventIndex).start();
+    QDateTime endTime(startTime);
     for (int i = mFirstEventIndex; i != mFirstEventIndex + mChildCount; ++i) {
-        endTime = qMax(mEvents.at(i).start().time().addSecs(mEvents.at(i).duration()), endTime);
+        endTime = qMax(mEvents.at(i).start().addSecs(mEvents.at(i).duration()), endTime);
     }
     mTitle = QString("%1 - %2").arg(startTime.toString("HH:mm")).arg(endTime.toString("HH:mm"));
 }
@@ -235,44 +235,31 @@ void EventModel::clearModel()
     reset();
 }
 
-void EventModel::loadEvents(const QDate &aDate, int aConferenceId)
-{
+
+void EventModel::loadEvents(const QDate &aDate, int aConferenceId) {
     clearModel();
-    // check for existence of the conference in the DB
-    if(Conference::getAll().count())
-    {
-        mEvents = Event::getByDate(QDate(aDate.year(), aDate.month(), aDate.day()), aConferenceId, "start, duration");
-    }
+    mEvents = Event::getByDate(QDate(aDate.year(), aDate.month(), aDate.day()), aConferenceId, "start, duration");
     createTimeGroups();
 }
 
-void EventModel::loadFavEvents(const QDate &aDate, int aConferenceId)
-{
+
+void EventModel::loadFavEvents(const QDate &aDate, int aConferenceId) {
     clearModel();
-    // check for existence of the conference in the DB
-    if(Conference::getAll().count())
-    {
-        mEvents = Event::getFavByDate(QDate(aDate.year(), aDate.month(), aDate.day()), aConferenceId);
-    }
+    mEvents = Event::getFavByDate(QDate(aDate.year(), aDate.month(), aDate.day()), aConferenceId);
     createTimeGroups();
 }
 
-int EventModel::loadSearchResultEvents(const QDate &aDate, int aConferenceId)
-{
-    clearModel();
-    // check for existence of the conference in the DB
-    if(Conference::getAll().count())
-    {
-        try{
-            mEvents = Event::getSearchResultByDate(QDate(aDate.year(), aDate.month(), aDate.day()), aConferenceId, "start, duration");
-        }
-        catch( OrmException &e  ){
-            qDebug() << "Event::getSearchResultByDate failed: " << e.text();
-        }
-        catch(...){
-            qDebug() << "Event::getSearchResultByDate failed";
-        }
 
+int EventModel::loadSearchResultEvents(const QDate &aDate, int aConferenceId) {
+    clearModel();
+    try {
+        mEvents = Event::getSearchResultByDate(QDate(aDate.year(), aDate.month(), aDate.day()), aConferenceId, "start, duration");
+    }
+    catch( OrmException &e  ){
+        qDebug() << "Event::getSearchResultByDate failed: " << e.text();
+    }
+    catch(...){
+        qDebug() << "Event::getSearchResultByDate failed";
     }
 
     createTimeGroups();
@@ -280,37 +267,28 @@ int EventModel::loadSearchResultEvents(const QDate &aDate, int aConferenceId)
     return mEvents.count();
 }
 
-void EventModel::loadEventsByTrack(const QDate &aDate, int aConferenceId)
-{
+
+void EventModel::loadEventsByTrack(const QDate &aDate, int aConferenceId) {
     clearModel();
-    if (Conference::getAll().count())
-    {
-        mEvents = Event::getByDate(QDate(aDate.year(), aDate.month(), aDate.day()), aConferenceId, "xid_track, start, duration");
-    }
+    mEvents = Event::getByDate(QDate(aDate.year(), aDate.month(), aDate.day()), aConferenceId, "xid_track, start, duration");
     createTrackGroups();
 }
 
-void EventModel::loadEventsByRoom(const QDate &aDate, int aConferenceId)
-{
+
+void EventModel::loadEventsByRoom(const QDate &aDate, int aConferenceId) {
     clearModel();
-    if (Conference::getAll().count())
-    {
-        mEvents = Event::getByDateAndRoom(QDate(aDate.year(), aDate.month(), aDate.day()), aConferenceId);
-    }
+    mEvents = Event::getByDateAndRoom(QDate(aDate.year(), aDate.month(), aDate.day()), aConferenceId);
     createRoomGroups();
 }
 
 
 void EventModel::loadConflictEvents(int aEventId, int aConferenceId) {
     clearModel();
-    // check for existence of the conference in the DB
-    if(Conference::getAll().count())
-    {
-        mEvents = Event::conflictEvents(aEventId, aConferenceId);
-    }
+    mEvents = Event::conflictEvents(aEventId, aConferenceId);
     createTimeGroups();
 }
 
+
 void EventModel::updateModel(int aEventId)
 {
     for(int i=0; i<mEvents.count(); i++)
