@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011-2012 Philipp Spitzer, gregor herrmann, Stefan Stahl
+ * Copyright (C) 2011-2013 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -21,7 +21,7 @@
 #ifndef ROOM_H_
 #define ROOM_H_
 
-#include <ormrecord.h>
+#include "ormrecord.h"
 
 class Room : public OrmRecord<Room>
 {
