@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011-2012 Philipp Spitzer, gregor herrmann, Stefan Stahl
+ * Copyright (C) 2011-2013 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -27,12 +27,11 @@
 
 #include <QDebug>
 
-ScheduleXmlParser::ScheduleXmlParser(QObject *aParent)
-    : QObject(aParent)
-{
+ScheduleXmlParser::ScheduleXmlParser(SqlEngine* sqlEngine, QObject *aParent): QObject(aParent),sqlEngine(sqlEngine) {
 }
 
-void ScheduleXmlParser::parseData(const QByteArray &aData, const QString& url)
+
+void ScheduleXmlParser::parseData(const QByteArray &aData, const QString& url, int conferenceId)
 {
     QDomDocument document;
     QString xml_error;
@@ -45,9 +44,8 @@ void ScheduleXmlParser::parseData(const QByteArray &aData, const QString& url)
 
     QDomElement scheduleElement = document.firstChildElement("schedule");
 
-    SqlEngine::beginTransaction();
+    sqlEngine->beginTransaction();
 
-    int confId = 0;
     QString conference_title;
     if (!scheduleElement.isNull())
     {
@@ -56,19 +54,18 @@ void ScheduleXmlParser::parseData(const QByteArray &aData, const QString& url)
         {
             emit(parsingScheduleBegin());
             QHash<QString,QString> conference;
-            conference["id"] = QString::number(0); // conference ID is assigned automatically, or obtained from the DB
+            conference["id"] = QString::number(conferenceId); // conference ID is assigned automatically if 0
             conference["title"] = conferenceElement.firstChildElement("title").text();
             conference["subtitle"] = conferenceElement.firstChildElement("subtitle").text();
             conference["venue"] = conferenceElement.firstChildElement("venue").text();
             conference["city"] = conferenceElement.firstChildElement("city").text();
             conference["start"] = conferenceElement.firstChildElement("start").text(); // date
             conference["end"] = conferenceElement.firstChildElement("end").text(); // date
-            conference["days"] = conferenceElement.firstChildElement("days").text(); // int
             conference["day_change"] = conferenceElement.firstChildElement("day_change").text(); // time
             conference["timeslot_duration"] = conferenceElement.firstChildElement("timeslot_duration").text(); // time
             conference["url"] = url;
-            SqlEngine::addConferenceToDB(conference);
-            confId = conference["id"].toInt();
+            sqlEngine->addConferenceToDB(conference, conferenceId);
+            conferenceId = conference["id"].toInt();
             conference_title = conference["title"];
         }
 
@@ -104,13 +101,13 @@ void ScheduleXmlParser::parseData(const QByteArray &aData, const QString& url)
                         QHash<QString,QString> room;
                         room["name"] = roomElement.attribute("name");
                         room["event_id"] = eventElement.attribute("id");
-                        room["conference_id"] = QString::number(confId,10);
-                        SqlEngine::addRoomToDB(room);
+                        room["conference_id"] = QString::number(conferenceId,10);
+                        sqlEngine->addRoomToDB(room);
 
                         // process event's nodes
                         QHash<QString,QString> event;
                         event["id"] = eventElement.attribute("id");;
-                        event["conference_id"] = QString::number(confId, 10);
+                        event["conference_id"] = QString::number(conferenceId, 10);
                         event["start"] = eventElement.firstChildElement("start").text(); // time eg. 10:00
                         event["date"] = dayElement.attribute("date"); // date eg. 2009-02-07
                         event["duration"] = eventElement.firstChildElement("duration").text(); // time eg. 00:30
@@ -123,9 +120,8 @@ void ScheduleXmlParser::parseData(const QByteArray &aData, const QString& url)
                         event["language"] = eventElement.firstChildElement("language").text(); // language eg. "English"
                         event["abstract"] = eventElement.firstChildElement("abstract").text(); // string
                         event["description"] = eventElement.firstChildElement("description").text(); // string
-                        SqlEngine::addEventToDB(event);
+                        sqlEngine->addEventToDB(event);
                         // process persons' nodes
-                        QList<QString> persons;
                         QDomElement personsElement = eventElement.firstChildElement("persons");
                         QDomNodeList personList = personsElement.elementsByTagName("person");
                         for(int i = 0;i < personList.count();i++){
@@ -133,9 +129,8 @@ void ScheduleXmlParser::parseData(const QByteArray &aData, const QString& url)
                             person["id"] = personList.at(i).toElement().attribute("id");
                             person["name"] = personList.at(i).toElement().text();
                             person["event_id"] = eventElement.attribute("id");
-                            person["conference_id"] = QString::number(confId, 10);
-                            //qDebug() << "adding Person: " << person["name"];
-                            SqlEngine::addPersonToDB(person);
+                            person["conference_id"] = QString::number(conferenceId, 10);
+                            sqlEngine->addPersonToDB(person);
                         }
                         // process links' nodes
                         QDomElement linksElement = eventElement.firstChildElement("links");
@@ -145,8 +140,8 @@ void ScheduleXmlParser::parseData(const QByteArray &aData, const QString& url)
                             link["name"] = linkList.at(i).toElement().text();
                             link["url"] = linkList.at(i).toElement().attribute("href");
                             link["event_id"] = eventElement.attribute("id");
-                            link["conference_id"] = QString::number(confId, 10);
-                            SqlEngine::addLinkToDB(link);
+                            link["conference_id"] = QString::number(conferenceId, 10);
+                            sqlEngine->addLinkToDB(link);
                         }
                         // emit signal to inform the user about the current status (how many events are parsed so far - expressed in %)
                         int status = currentEvent * 100 / totalEventsCount;
@@ -156,9 +151,9 @@ void ScheduleXmlParser::parseData(const QByteArray &aData, const QString& url)
             } // parsing room elements
         } // parsing day elements
     } // schedule element
-    SqlEngine::commitTransaction();
+    sqlEngine->commitTransaction();
     if (!conference_title.isNull()) {
-        emit parsingScheduleEnd(conference_title);
+        emit parsingScheduleEnd(conferenceId);
     } else {
         error_message("Could not parse schedule");
     }
