@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011-2012 Philipp Spitzer, gregor herrmann, Stefan Stahl
+ * Copyright (C) 2011-2013 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -21,20 +21,23 @@
 #define SCHEDULEXMLPARSER_H_
 
 #include <QObject>
+#include "sqlengine.h"
 
 class ScheduleXmlParser : public QObject
 {
     Q_OBJECT
+    private:
+        SqlEngine* sqlEngine;
     public:
-        ScheduleXmlParser (QObject *aParent = NULL);
+        ScheduleXmlParser(SqlEngine* sqlEngine, QObject *aParent = NULL);
 
     public slots:
-        void parseData(const QByteArray &aData, const QString& url);
+        void parseData(const QByteArray &aData, const QString& url, int conferenceId);
 
     signals:
         void progressStatus(int aStatus);
         void parsingScheduleBegin();
-        void parsingScheduleEnd(const QString& title);
+        void parsingScheduleEnd(int conferenceId);
 };
 
 #endif /* SCHEDULEXMLPARSER_H_ */
